@@ -51,7 +51,7 @@ void init_datefmt(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto result = DateFormat::createInstanceForSkeleton(skeleton, locale, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -63,7 +63,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = DateFormat::createInstanceForSkeleton(skeleton, locale, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -75,7 +75,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = DateFormat::createInstanceForSkeleton(skeleton, locale, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -88,7 +88,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = DateFormat::createInstanceForSkeleton(skeleton, locale, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -99,7 +99,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = DateFormat::createInstanceForSkeleton(skeleton, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -111,7 +111,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = DateFormat::createInstanceForSkeleton(skeleton, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -131,7 +131,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(cal, append_to, pos_iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -144,7 +144,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(obj, append_to, pos, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -157,7 +157,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(obj, append_to, pos_iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -178,7 +178,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(date, append_to, pos_iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -190,7 +190,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(obj, append_to, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -214,7 +214,7 @@ void init_datefmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = self.getBooleanAttribute(attr, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -228,13 +228,13 @@ void init_datefmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = self.getContext(type, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
       py::arg("type_"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 53)
-  // TODO: Implement "const NumberFormat *icu::DateFormat::getNumberFormat(void)".
+  df.def("get_number_format", &DateFormat::getNumberFormat, py::return_value_policy::reference);
   df.def(
       "get_time_zone",
       [](const DateFormat &self) -> std::variant<const BasicTimeZone *, const TimeZone *> {
@@ -272,7 +272,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.parse(text, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -284,7 +284,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.parse(text, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -304,7 +304,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.parseObject(source, result, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("source"), py::arg("result"))
@@ -316,7 +316,7 @@ void init_datefmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.parseObject(source, result, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("source"), py::arg("result"));
@@ -327,7 +327,7 @@ void init_datefmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto &result = self.setBooleanAttribute(attr, new_value, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -342,12 +342,12 @@ void init_datefmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         self.setContext(value, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
       },
       py::arg("value"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 53)
   df.def("set_lenient", &DateFormat::setLenient, py::arg("lenient"));
-  // TODO: Implement "void icu::DateFormat::setNumberFormat(const NumberFormat &newNumberFormat)".
+  df.def("set_number_format", &DateFormat::setNumberFormat, py::arg("new_number_format"));
   df.def("set_time_zone", &DateFormat::setTimeZone, py::arg("zone"));
 }
