@@ -11,6 +11,7 @@
 
 using namespace icu;
 
+void init_alphaindex(py::module &m);
 void init_appendable(py::module &m);
 void init_char16ptr(py::module &m);
 void init_coleitr(py::module &m);
@@ -34,6 +35,7 @@ void init_formattedvalue(py::module &m);
 void init_fpositer(py::module &m);
 void init_gregocal(py::module &m);
 void init_idna(py::module &m);
+void init_listformatter(py::module &m);
 void init_localebuilder(py::module &m);
 void init_localematcher(py::module &m);
 void init_locid(py::module &m, py::class_<Locale, UObject> &loc);
@@ -55,6 +57,7 @@ void init_plurrule(py::module &m, py::class_<PluralRules, UObject> &pr);
 void init_rbbi(py::module &m);
 void init_rbnf(py::module &m);
 void init_regex(py::module &m);
+void init_reldatefmt(py::module &m);
 void init_resbund(py::module &m);
 void init_schriter(py::module &m);
 void init_selfmt(py::module &m);
@@ -87,6 +90,7 @@ void init_udisplaycontext(py::module &m);
 void init_uenum(py::module &m);
 void init_uformattedvalue(py::module &m);
 void init_uidna(py::module &m);
+void init_ulistformatter(py::module &m);
 void init_uloc(py::module &m);
 void init_uniset(py::module &m);
 void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class_<UnicodeString, Replaceable> &us);
@@ -96,6 +100,7 @@ void init_unumberformatter(py::module &m);
 void init_unumberrangeformatter(py::module &m);
 void init_upluralrules(py::module &m);
 void init_uregex(py::module &m);
+void init_ureldatefmt(py::module &m);
 void init_ures(py::module &m);
 void init_uscript(py::module &m);
 void init_usearch(py::module &m);
@@ -225,11 +230,13 @@ PYBIND11_MODULE(MODULE_NAME, m) {
 
   init_dtptngen(m);      // icu::DateTimePatternGenerator
   init_idna(m);          // icu::IDNA
+  init_listformatter(m); // icu::ListFormatter
   init_localebuilder(m); // icu::LocaleBuilder
   init_localematcher(m); // icu::LocaleMatcher
   init_locid(m, loc);    // icu::Locale
   init_rbbi(m);          // icu::RuleBasedBreakIterator
   init_regex(m);         // icu::RegexPattern, icu::RegexMatcher
+  init_reldatefmt(m);    // icu::RelativeDateTimeFormatter
   init_resbund(m);       // icu::ResourceBundle
   init_sortkey(m);       // icu::CollationKey
 
@@ -239,6 +246,8 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_stsearch(m);    // icu::StringSearch
   init_translit(m);    // icu::Transliterator
 
+  init_alphaindex(m); // icu::AlphabeticIndex
+
   init_unistr(m, rep, us); // icu::UnicodeString
 
   init_ubidi(m);
@@ -258,6 +267,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_uenum(m);
   init_uformattedvalue(m);
   init_uidna(m);
+  init_ulistformatter(m);
   init_uloc(m);
   init_unorm2(m);
   init_unum(m);
@@ -265,6 +275,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_unumberrangeformatter(m);
   init_upluralrules(m);
   init_uregex(m);
+  init_ureldatefmt(m);
   init_ures(m);
   init_uscript(m);
   init_usearch(m);
