@@ -27,8 +27,8 @@ void init_ures(py::module &m) {
       .value("RES_INT_VECTOR", RES_INT_VECTOR)
       .value("RES_RESERVED", RES_RESERVED)
       .value("URES_LIMIT", URES_LIMIT)
-#endif  // U_HIDE_DEPRECATED_API
-      ; // <UResType>
+#endif // U_HIDE_DEPRECATED_API
+      .export_values();
 
   py::class_<_UResourceBundlePtr>(m, "_UResourceBundlePtr");
 
@@ -41,7 +41,7 @@ void init_ures(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto resource_bundle = ures_open(package_name, locale, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return std::make_unique<_UResourceBundlePtr>(resource_bundle);
       },
@@ -52,7 +52,7 @@ void init_ures(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto resource_bundle = ures_openDirect(package_name, locale, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return std::make_unique<_UResourceBundlePtr>(resource_bundle);
       },
