@@ -250,7 +250,7 @@ void init_uscript(py::module &m) {
       "uscript_get_code",
       [](const char *name_or_abbr_or_locale) {
         UErrorCode error_code = U_ZERO_ERROR;
-        const auto length = uscript_getCode(name_or_abbr_or_locale, NULL, 0, &error_code);
+        const auto length = uscript_getCode(name_or_abbr_or_locale, nullptr, 0, &error_code);
         std::vector<UScriptCode> result(length);
         error_code = U_ZERO_ERROR;
         uscript_getCode(name_or_abbr_or_locale, result.data(), (int32_t)result.size(), &error_code);
@@ -266,7 +266,7 @@ void init_uscript(py::module &m) {
       "uscript_get_sample_string",
       [](UScriptCode script) {
         UErrorCode error_code = U_ZERO_ERROR;
-        const auto length = uscript_getSampleString(script, NULL, 0, &error_code);
+        const auto length = uscript_getSampleString(script, nullptr, 0, &error_code);
         std::u16string result(length, u'\0');
         error_code = U_ZERO_ERROR;
         uscript_getSampleString(script, result.data(), (int32_t)result.size(), &error_code);
@@ -294,7 +294,7 @@ void init_uscript(py::module &m) {
       "uscript_get_script_extensions",
       [](UChar32 c) {
         UErrorCode error_code = U_ZERO_ERROR;
-        const auto length = uscript_getScriptExtensions(c, NULL, 0, &error_code);
+        const auto length = uscript_getScriptExtensions(c, nullptr, 0, &error_code);
         std::vector<UScriptCode> result(length);
         error_code = U_ZERO_ERROR;
         uscript_getScriptExtensions(c, result.data(), (int32_t)result.size(), &error_code);
