@@ -6,11 +6,17 @@ from icupy import (
 
 def test_api():
     coll = Collator.create_instance(Locale("es"))
+
+    # CollationElementIterator *
+    # icu::RuleBasedCollator::createCollationElementIterator(
+    #       const UnicodeString &source
+    # )
     source = UnicodeString("cha")
     it1 = coll.create_collation_element_iterator(source)
     assert isinstance(it1, CollationElementIterator)
     assert it1.get_offset() == 0
 
+    # int32_t icu::CollationElementIterator::next(UErrorCode &status)
     order1 = it1.next()
     assert order1 != CollationElementIterator.NULLORDER
     order2 = it1.next()
@@ -19,21 +25,29 @@ def test_api():
     assert order3 != CollationElementIterator.NULLORDER
     assert it1.next() == CollationElementIterator.NULLORDER
 
+    # int32_t icu::CollationElementIterator::getOffset(void)
     assert it1.get_offset() != 0
     it1.reset()
     assert it1.get_offset() == 0
 
+    # void icu::CollationElementIterator::setOffset(
+    #       int32_t newOffset,
+    #       UErrorCode &status
+    # )
     it1.set_offset(1)
     assert list(it1) == [order1, order2, order3]
 
+    # int32_t icu::CollationElementIterator::getMaxExpansion(int32_t order)
     assert it1.get_max_expansion(order1) == 1
     assert it1.get_max_expansion(order2) == 1
     assert it1.get_max_expansion(order3) == 1
 
+    # UBool icu::CollationElementIterator::isIgnorable(int32_t order)
     assert not CollationElementIterator.is_ignorable(order1)
     assert not CollationElementIterator.is_ignorable(order2)
     assert not CollationElementIterator.is_ignorable(order3)
 
+    # int32_t icu::CollationElementIterator::previous(UErrorCode &status)
     it1.set_offset(3)
     assert it1.get_offset() == 3
     assert it1.previous() == order3
@@ -41,13 +55,17 @@ def test_api():
     assert it1.previous() == order1
     assert it1.previous() == CollationElementIterator.NULLORDER
 
+    # icu::CollationElementIterator::CollationElementIterator(
+    #       const CollationElementIterator &other
+    # )
     it2 = CollationElementIterator(it1)
     assert it1 == it2
     assert not (it1 != it2)
 
     # [1]
-    # void CollationElementIterator::setText(CharacterIterator &str,
-    #                                        UErrorCode &status
+    # void icu::CollationElementIterator::setText(
+    #       CharacterIterator &str,
+    #       UErrorCode &status
     # )
     source = StringCharacterIterator(UnicodeString("ca"))
     it2.set_text(source)
@@ -61,14 +79,20 @@ def test_api():
     assert not (it1 != it2)
 
     # [2]
-    # void CollationElementIterator::setText(const UnicodeString &str,
-    #                                        UErrorCode &status
+    # void icu::CollationElementIterator::setText(
+    #       const UnicodeString &str,
+    #       UErrorCode &status
     # )
     source = UnicodeString("cha")
     it2.set_text(source)
     assert it1 == it2
     assert not (it1 != it2)
 
+    it2.set_text("cha")
+    assert it1 == it2
+    assert not (it1 != it2)
+
+    # int32_t icu::CollationElementIterator::primaryOrder(int32_t order)
     assert (CollationElementIterator.primary_order(order1)
             == CollationElementIterator.primary_order(it2.next()))
     assert (CollationElementIterator.primary_order(order2)
@@ -76,6 +100,7 @@ def test_api():
     assert (CollationElementIterator.primary_order(order3)
             == CollationElementIterator.primary_order(it2.next()))
 
+    # int32_t icu::CollationElementIterator::secondaryOrder(int32_t order)
     it2.reset()
     assert (CollationElementIterator.secondary_order(order1)
             == CollationElementIterator.secondary_order(it2.next()))
@@ -84,6 +109,7 @@ def test_api():
     assert (CollationElementIterator.secondary_order(order3)
             == CollationElementIterator.secondary_order(it2.next()))
 
+    # int32_t icu::CollationElementIterator::tertiaryOrder(int32_t order)
     it2.reset()
     assert (CollationElementIterator.tertiary_order(order1)
             == CollationElementIterator.tertiary_order(it2.next()))
@@ -92,6 +118,7 @@ def test_api():
     assert (CollationElementIterator.tertiary_order(order3)
             == CollationElementIterator.tertiary_order(it2.next()))
 
+    # int32_t icu::CollationElementIterator::strengthOrder(int32_t order)
     coll.set_attribute(UColAttribute.UCOL_STRENGTH,
                        UColAttributeValue.UCOL_PRIMARY)
     assert it1.strength_order(order1) == order1 & 0xffff0000
