@@ -1,12 +1,55 @@
 import pytest
 from icupy import (
-    ErrorCode, ICUException, UErrorCode, U_ICU_VERSION_MAJOR_NUM,
+    ErrorCode, ICUError, UErrorCode, U_ICU_VERSION_MAJOR_NUM,
     u_failure, u_get_version, u_success, u_version_from_string,
     u_version_to_string,
 )
 
 
+def test_icu_error():
+    assert issubclass(ICUError, Exception)
+
+    with pytest.raises(ICUError) as exc_info:
+        _ = u_version_to_string([1, 2, 3])
+    ex = exc_info.value
+    assert isinstance(ex, ICUError)
+    assert len(ex.args) == 1
+    error_code = ex.args[0]
+    assert isinstance(error_code, ErrorCode)
+
+    # const char *icu::ErrorCode::errorName()
+    error_name = error_code.error_name
+    assert isinstance(error_name, str)
+    assert error_name == "U_ILLEGAL_ARGUMENT_ERROR"
+
+    # UErrorCode icu::ErrorCode::get()
+    status = error_code.get()
+    assert isinstance(status, UErrorCode)
+    assert status == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
+
+    # ErrorCode.__eq__(self, other: UErrorCode) -> bool
+    assert error_code == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
+
+    if U_ICU_VERSION_MAJOR_NUM >= 63:
+        from icupy import Locale
+
+        with pytest.raises(ICUError) as exc_info:
+            _ = Locale.for_language_tag("x")
+        ex = exc_info.value
+        assert isinstance(ex, ICUError)
+        assert len(ex.args) == 2
+        assert isinstance(ex.args[0], ErrorCode)  # icu::ErrorCode
+        assert isinstance(ex.args[1], str)  # An error message
+
+
+# TODO: Remove test_icu_exception().
 def test_icu_exception():
+    """Backward compatibility test.
+    ICUException is deprecated. Use ICUError instead.
+    """
+
+    from icupy import ICUException
+
     assert issubclass(ICUException, Exception)
 
     with pytest.raises(ICUException) as exc_info:
@@ -88,11 +131,11 @@ def test_u_version_to_string():
     assert isinstance(version_string, str)
     assert version_string == "123.45.67.89"
 
-    with pytest.raises(ICUException) as exc_info:
+    with pytest.raises(ICUError) as exc_info:
         _ = u_version_to_string([1, 2, 3])
     assert exc_info.value.args[0] == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
 
-    with pytest.raises(ICUException) as exc_info:
+    with pytest.raises(ICUError) as exc_info:
         _ = u_version_to_string([1, 2, 3, 4, 5])
     assert exc_info.value.args[0] == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
 
